@@ -1,4 +1,4 @@
-/* ulogd_PGSQL.c, Version $Revision: 714 $
+/* ulogd_PGSQL.c, Version $Revision: 6404 $
  *
  * ulogd output plugin for logging to a PGSQL database
  *
@@ -85,7 +85,7 @@ static config_entry_t schema_ce = {
 	.key = "schema", 
 	.type = CONFIG_TYPE_STRING,
 	.options = CONFIG_OPT_NONE,
-	.u.string = "public",
+	.u = { .string = "public" },
 };
 
 static config_entry_t port_ce = {
@@ -197,6 +197,8 @@ static int pgsql_output(ulog_iret_t *result)
 		return 1;
 	}
 
+	PQclear(pgres);
+
 	return 0;
 }
 
